@@ -6,11 +6,11 @@ import inspect
 import logging
 import re
 import time
-from typing import Any, Awaitable, Callable, Dict, List, Match, Optional, Set, Tuple, Union, cast
+from typing import Any, Callable, Dict, List, Match, Optional, Set, Tuple, Union, cast
 
 import aioamqp
 
-from tomodachi.helpers.dict import merge_dicts
+from tomodachi.helpers.dict import get_item_by_path, merge_dicts
 from tomodachi.helpers.execution_context import (
     decrease_execution_context_value,
     increase_execution_context_value,
@@ -58,9 +58,10 @@ class AmqpChannelClosed(AmqpException):
 
 
 class AmqpTransport(Invoker):
-    channel = None  # type: Any
-    protocol = None  # type: Any
-    transport = None  # type: Any
+    channel: Any = None
+    protocol: Any = None
+    transport: Any = None
+    exchange_name: str
 
     @classmethod
     async def publish(
@@ -77,7 +78,7 @@ class AmqpTransport(Invoker):
         **kwargs: Any,
     ) -> None:
         if not cls.channel:
-            await cls.connect(cls, service, service.context)
+            await cls.connect(service, service.context)
         exchange_name = exchange_name or cls.exchange_name or "amq.topic"
 
         if message_envelope == MESSAGE_ENVELOPE_DEFAULT and message_protocol != MESSAGE_ENVELOPE_DEFAULT:
@@ -107,12 +108,12 @@ class AmqpTransport(Invoker):
                     )
                     success = True
                 except AssertionError:
-                    await cls.connect(cls, service, service.context)
+                    await cls.connect(service, service.context)
 
         if wait:
             await _publish_message()
         else:
-            loop = asyncio.get_event_loop()  # type: Any
+            loop: Any = asyncio.get_event_loop()
             loop.create_task(_publish_message())
 
     @classmethod
@@ -159,7 +160,7 @@ class AmqpTransport(Invoker):
 
     @classmethod
     def get_queue_name(
-        cls, routing_key: str, func_name: str, _uuid: str, competing_consumer: bool, context: Dict
+        cls, routing_key: str, func_name: str, _uuid: str, competing_consumer: Optional[bool], context: Dict
     ) -> str:
         if not competing_consumer:
             queue_name = hashlib.sha256("{}{}{}".format(routing_key, func_name, _uuid).encode("utf-8")).hexdigest()
@@ -176,8 +177,9 @@ class AmqpTransport(Invoker):
             return "{}{}".format(context.get("options", {}).get("amqp", {}).get("queue_name_prefix"), queue_name)
         return queue_name
 
+    @classmethod
     async def subscribe_handler(
-        cls: Any,
+        cls,
         obj: Any,
         context: Dict,
         func: Any,
@@ -209,7 +211,7 @@ class AmqpTransport(Invoker):
             if envelope_kwargs_validation_func:
                 envelope_kwargs_validation_func(**parser_kwargs)
 
-        _callback_kwargs = callback_kwargs  # type: Any
+        _callback_kwargs: Any = callback_kwargs
         values = inspect.getfullargspec(func)
         if not _callback_kwargs:
             _callback_kwargs = (
@@ -224,7 +226,7 @@ class AmqpTransport(Invoker):
             )
         else:
             _callback_kwargs = {k: None for k in _callback_kwargs if k != "self"}
-        original_kwargs = {k: v for k, v in _callback_kwargs.items()}  # type: Dict[str, Any]
+        original_kwargs: Dict[str, Any] = {k: v for k, v in _callback_kwargs.items()}
 
         async def handler(payload: Any, delivery_tag: Any, routing_key: str) -> Any:
             kwargs = dict(original_kwargs)
@@ -269,7 +271,7 @@ class AmqpTransport(Invoker):
                             not isinstance(message, dict) or "routing_key" not in message
                         ):
                             kwargs["routing_key"] = routing_key
-                except Exception as e:
+                except (Exception, asyncio.CancelledError, BaseException) as e:
                     logging.getLogger("exception").exception("Uncaught exception: {}".format(str(e)))
                     if message is not False and not message_uuid:
                         await cls.channel.basic_client_ack(delivery_tag)
@@ -301,7 +303,7 @@ class AmqpTransport(Invoker):
                         routine = func(*(obj, message, *a), **kw)
                     else:
                         routine = func(*(obj, *a), **kw)
-                except Exception as e:
+                except (Exception, asyncio.CancelledError, BaseException) as e:
                     logging.getLogger("exception").exception("Uncaught exception: {}".format(str(e)))
                     if issubclass(
                         e.__class__,
@@ -314,10 +316,10 @@ class AmqpTransport(Invoker):
                     await cls.channel.basic_client_ack(delivery_tag)
                     return
 
-                if isinstance(routine, Awaitable):
+                if inspect.isawaitable(routine):
                     try:
                         return_value = await routine
-                    except Exception as e:
+                    except (Exception, asyncio.CancelledError, BaseException) as e:
                         logging.getLogger("exception").exception("Uncaught exception: {}".format(str(e)))
                         if issubclass(
                             e.__class__,
@@ -349,10 +351,11 @@ class AmqpTransport(Invoker):
         context["_amqp_subscribers"] = context.get("_amqp_subscribers", [])
         context["_amqp_subscribers"].append((routing_key, exchange_name, competing, queue_name, func, handler))
 
-        start_func = cls.subscribe(cls, obj, context)
+        start_func = cls.subscribe(obj, context)
         return (await start_func) if start_func else None
 
-    async def connect(cls: Any, obj: Any, context: Dict) -> Any:
+    @classmethod
+    async def connect(cls, obj: Any, context: Dict) -> Any:
         logging.getLogger("aioamqp.protocol").setLevel(logging.WARNING)
         logging.getLogger("aioamqp.channel").setLevel(logging.WARNING)
 
@@ -365,6 +368,7 @@ class AmqpTransport(Invoker):
         heartbeat = context.get("options", {}).get("amqp", {}).get("heartbeat", 60)
 
         try:
+            protocol: Any
             transport, protocol = await aioamqp.connect(
                 host=host,
                 port=port,
@@ -416,7 +420,8 @@ class AmqpTransport(Invoker):
 
         return channel
 
-    async def subscribe(cls: Any, obj: Any, context: Dict) -> Optional[Callable]:
+    @classmethod
+    async def subscribe(cls, obj: Any, context: Dict) -> Optional[Callable]:
         if context.get("_amqp_subscribed"):
             return None
         context["_amqp_subscribed"] = True
@@ -431,7 +436,11 @@ class AmqpTransport(Invoker):
         )
 
         cls.channel = None
-        channel = await cls.connect(cls, obj, context)
+        channel = await cls.connect(obj, context)
+        queue_prefetch_count = get_item_by_path(context, "options.amqp.qos.queue_prefetch_count", 100)
+        global_prefetch_count = get_item_by_path(context, "options.amqp.qos.global_prefetch_count", 400)
+        await channel.basic_qos(prefetch_count=queue_prefetch_count, prefetch_size=0, connection_global=False)
+        await channel.basic_qos(prefetch_count=global_prefetch_count, prefetch_size=0, connection_global=True)
 
         async def _subscribe() -> None:
             async def declare_queue(
